==> haskell-indexed-profunctors-0.1.1.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-indexed-profunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 indexed-profunctors
version:              0.1.1.1
visibility:           public
id:                   indexed-profunctors-0.1.1.1-FtNuykj07dlNVtQ9HC5Fh
key:                  indexed-profunctors-0.1.1.1-FtNuykj07dlNVtQ9HC5Fh
license:              BSD-3-Clause
maintainer:           optics@well-typed.com
author:               Adam Gundry, Andres Löh, Andrzej Rybczak, Oleg Grenrus
synopsis:             Utilities for indexed profunctors
description:
    This package contains basic definitions related to indexed profunctors.  These
    are primarily intended as internal utilities to support the @optics@ and
    @generic-lens@ package families.

category:             Data, Optics, Lenses, Profunctors
abi:                  7189bc39f7c3ba9c23d22370f6b40242
exposed:              True
exposed-modules:      Data.Profunctor.Indexed
import-dirs:          /usr/lib/ghc-9.0.2/site-local/indexed-profunctors-0.1.1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/indexed-profunctors-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-indexed-profunctors
hs-libraries:         HSindexed-profunctors-0.1.1.1-FtNuykj07dlNVtQ9HC5Fh
depends:              base-4.15.1.0
haddock-interfaces:
    /usr/share/doc/haskell-indexed-profunctors/html/indexed-profunctors.haddock

haddock-html:         /usr/share/doc/haskell-indexed-profunctors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-indexed-profunctors-0.1.1.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-indexed-profunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 indexed-profunctors
version:              0.1.1.1
visibility:           public
id:                   indexed-profunctors-0.1.1.1-75fifDzrRPoIEkrRsA78TU
key:                  indexed-profunctors-0.1.1.1-75fifDzrRPoIEkrRsA78TU
license:              BSD-3-Clause
maintainer:           optics@well-typed.com
author:               Adam Gundry, Andres Löh, Andrzej Rybczak, Oleg Grenrus
synopsis:             Utilities for indexed profunctors
description:
    This package contains basic definitions related to indexed profunctors.  These
    are primarily intended as internal utilities to support the @optics@ and
    @generic-lens@ package families.

category:             Data, Optics, Lenses, Profunctors
abi:                  9a49097748926c5a8ee945683a23344f
exposed:              True
exposed-modules:      Data.Profunctor.Indexed
import-dirs:          /usr/lib/ghc-9.2.8/site-local/indexed-profunctors-0.1.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/indexed-profunctors-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-indexed-profunctors
hs-libraries:         HSindexed-profunctors-0.1.1.1-75fifDzrRPoIEkrRsA78TU
depends:              base-4.16.4.0
haddock-interfaces:
    /usr/share/doc/haskell-indexed-profunctors/html/indexed-profunctors.haddock

haddock-html:         /usr/share/doc/haskell-indexed-profunctors/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
